#!/bin/sh

# The source here is entirely from a samba-3.0.* distribution
# EXCEPT for the following:
#	samba-3.0.sh		this file -- drives the build
#	samba-3.0-patches	the modifications to be applied
#	samba.desktop           a reference for the GUI
#	samba.inetd.sed         inetd config
#	samba.init              our /etc/init.d script for sysvinit
#	samba.services.sed      services entries for the SMB services
#	samba.pam               the samba enablement file for pam
#
# Multibyte has been removed since the "-mb" option used for Samba-2.2.8
# that apparently differentiated samba and sambamb has NO EFFECT in the
# samba config scripts.  samba-2.2/packaging/Caldera/UnixWare/* ignore
# this option.

set -x
set -e

# First apply the patches
[ -f samba-3.0-been-patched ] || {
	patch -p1 -i samba-3.0-patches || {
		echo '@#%$!: ERROR: something failed patching samba-3.0' 1>&2
		exit 2
	}
	date >samba-3.0-been-patched
}

cd source
cat <<EOM > config.cache
ac_cv_path_AWK=\${ac_cv_path_AWK=/bin/awk}
ac_cv_prog_AWK=\${ac_cv_prog_AWK=/bin/awk}
samba_cv_optimize_out_funcation_calls=\${samba_cv_optimize_out_funcation_calls=no}
EOM
# technically, samba_cv_optimize_out_funcation_calls=yes, but
# msdfs/msdfs.c@753,754 has a bad optimize, so it's turned off above

chmod +x configure
INSTALL=/usr/ucb/install ./configure -C --prefix=/usr/lib/samba --disable-static --with-profile --with-syslog --with-utmp --with-vfs --with-sambabook=/usr/lib/samba/swat/using_samba --with-pam --with-pam_smbpass --with-libiconv=/usr --mandir=/usr/share/man
make install DESTDIR=$ROOT/$MACH

mkdir -p $ROOT/$MACH/etc/init.d $ROOT/$MACH/usr/share/meta/doc/HelpTopics/DOShome/DOSgroup
/usr/ucb/install ../samba.init $ROOT/$MACH/etc/init.d/samba
/usr/ucb/install ../samba.desktop $ROOT/$MACH/usr/share/meta/doc/HelpTopics/DOShome/DOSgroup/samba.desktop
cp ../samba.inetd.sed ../samba.services.sed $ROOT/$MACH/tmp

# Copy over the pam related stuff
mkdir -p $ROOT/$MACH/usr/lib/security
cp bin/pam_smbpass.so $ROOT/$MACH/usr/lib/security
mkdir -p $ROOT/$MACH/etc/pam.d
cp ../samba.pam $ROOT/$MACH/etc/pam.d/samba

# Copy over a sample config file

cp ../examples/smb.conf.default $ROOT/$MACH/usr/lib/samba/lib/

exit 0
